pub struct ResultSlot {
handler: Arc<dyn ResultHandler + Send + Sync>,
storage: SlotStorage,
}Expand description
A fake Slot that contains the resulting item of f.e. a craft
Fields
handler: Arc<dyn ResultHandler + Send + Sync>storage: SlotStorageImplementations
Sourceimpl ResultSlot
impl ResultSlot
Sourcepub fn new(handler: impl ResultHandler + 'static) -> Self
pub fn new(handler: impl ResultHandler + 'static) -> Self
Creates a new ResultSlot backed by the handler’s result container.
Sourcepub(crate) fn result_container(&self) -> &ContainerRef
pub(crate) fn result_container(&self) -> &ContainerRef
Returns the result container this slot derived from its handler.